@@ -14,4 +14,4 @@ q :: QC.Testable a => String -> a -> HU.Test
 q = qc2hu 250
 
 qverbose :: QC.Testable a => String -> a -> HU.Test
-qverbose = qc2huVerbose 250
+qverbose = qc2hu 250
